# English (EN)
from trallie.prompts.en.data_extraction_prompts import (
    FEW_SHOT_EXTRACTION_SYSTEM_PROMPT,
    ZERO_SHOT_EXTRACTION_SYSTEM_PROMPT,
)

from trallie.prompts.en.schema_generation_prompts import (
    FEW_SHOT_GENERATION_SYSTEM_PROMPT,
    ZERO_SHOT_GENERATION_SYSTEM_PROMPT,
    FEW_SHOT_GENERATION_LONG_DOCUMENT_SYSTEM_PROMPT,
)

# German (DE)
from trallie.prompts.de.schema_generation_prompts import FEW_SHOT_GENERATION_LONG_DOCUMENT_SYSTEM_PROMPT_DE
from trallie.prompts.de.data_extraction_prompts import FEW_SHOT_EXTRACTION_SYSTEM_PROMPT_DE

# French (FR)
from trallie.prompts.fr.schema_generation_prompts import FEW_SHOT_GENERATION_LONG_DOCUMENT_SYSTEM_PROMPT_FR
from trallie.prompts.fr.data_extraction_prompts import FEW_SHOT_EXTRACTION_SYSTEM_PROMPT_FR

# Spanish (ES)
from trallie.prompts.es.schema_generation_prompts import FEW_SHOT_GENERATION_LONG_DOCUMENT_SYSTEM_PROMPT_ES
from trallie.prompts.es.data_extraction_prompts import FEW_SHOT_EXTRACTION_SYSTEM_PROMPT_ES

# Italian (IT)
from trallie.prompts.it.schema_generation_prompts import FEW_SHOT_GENERATION_LONG_DOCUMENT_SYSTEM_PROMPT_IT
from trallie.prompts.it.data_extraction_prompts import FEW_SHOT_EXTRACTION_SYSTEM_PROMPT_IT
